<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>CountdownTooltip</name>
    <message>
        <source>Click the tray icon 
or press the shortcut again to stop recording</source>
        <translation>Klicken Sie auf das Taskleistensymbol 
oder drücken Sie die Tastenkombination erneut, um die Aufnahme zu stoppen</translation>
    </message>
    <message>
        <source>Do not rotate your screen during recording</source>
        <translation>Drehen Sie Ihren Bildschirm während der Aufnahme nicht</translation>
    </message>
</context>
<context>
    <name>IconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Bildschirmaufnahme</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Wird aufgenommen</translation>
    </message>
</context>
<context>
    <name>MainToolWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>Schließen (Esc)</translation>
    </message>
    <message>
        <source>Copy to clipboard (Enter)</source>
        <translation>In die Zwischenablage kopieren (Enter)</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Screen Capture</source>
        <translation>Bildschirmaufnahme</translation>
    </message>
    <message>
        <source>Save failed. Please save it in your home directory.</source>
        <translation>Speichern fehlgeschlagen. Bitte speichern Sie in Ihrem Heimverzeichnis.</translation>
    </message>
    <message>
        <source>View</source>
        <translation>Ansicht</translation>
    </message>
    <message>
        <source>Screenshot finished</source>
        <translation>Bildschirmaufnahme beendet</translation>
    </message>
    <message>
        <source>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</source>
        <translation>PNG (*.png);;JPEG (*.jpg *.jpeg);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</source>
        <translation>JPEG (*.jpg *.jpeg);;PNG (*.png);;BMP (*.bmp)</translation>
    </message>
    <message>
        <source>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</source>
        <translation>BMP (*.bmp);;JPEG (*.jpg *.jpeg);;PNG (*.png)</translation>
    </message>
    <message>
        <source>select-area</source>
        <translation>Auswahlbereich</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Gespeichert unter %1</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorieren</translation>
    </message>
    <message>
        <source>Clipboard</source>
        <translation>Zwischenablage</translation>
    </message>
    <message>
        <source>Saving the screen recording file, please wait...</source>
        <translation>Die Bildschirmaufnahme-Datei wird gespeichert, bitte warten ...</translation>
    </message>
    <message>
        <source>As the window effect is disabled during the process, the recording has to be stopped</source>
        <translation>Da der Fenstereffekt während des Vorgangs deaktiviert ist, muss die Aufnahme gestoppt werden</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Bildschirmaufnahme</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Bildlaufaufnahme</translation>
    </message>
    <message>
        <source>Pin Screenshots</source>
        <translation>Bildschirmfotos anheften</translation>
    </message>
    <message>
        <source>deepin-screen-recorder</source>
        <translation>Deepin Bildschirmaufnahme</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Ordner öffnen</translation>
    </message>
    <message>
        <source>Screenshot finished and copy to clipboard</source>
        <translation>Bildschirmaufnahme beendet und in die Zwischenablage kopiert</translation>
    </message>
</context>
<context>
    <name>MenuController</name>
    <message>
        <source>Undo</source>
        <translation>Rückgängig</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Beenden</translation>
    </message>
</context>
<context>
    <name>PinSaveMenuManager</name>
    <message>
        <source>Each inquiry</source>
        <translation>Jede Frage</translation>
    </message>
    <message>
        <source>Specified Location</source>
        <translation>Ange Ort</translation>
    </message>
    <message>
        <source>Set a path on save</source>
        <translation>Beim Speichern einen Pfad festlegen</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>Beim Speichern den Pfad ändern</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Pin Screenshots</source>
        <translation>Bildschirmfotos anheften</translation>
    </message>
</context>
<context>
    <name>QuickPanelWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Bildschirmaufnahme</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Aufnehmen</translation>
    </message>
</context>
<context>
    <name>RecordIconWidget</name>
    <message>
        <source>Screenshot</source>
        <translation>Bildschirmaufnahme</translation>
    </message>
    <message>
        <source>Recording</source>
        <translation>Wird aufgenommen</translation>
    </message>
</context>
<context>
    <name>RecordProcess</name>
    <message>
        <source>View</source>
        <translation>Ansicht</translation>
    </message>
    <message>
        <source>Recording finished</source>
        <translation>Aufnahme beendet</translation>
    </message>
    <message>
        <source>Saved to %1</source>
        <translation>Gespeichert unter %1</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Aufnehmen</translation>
    </message>
    <message>
        <source>Open Folder</source>
        <translation>Ordner öffnen</translation>
    </message>
</context>
<context>
    <name>SaveMenuManager</name>
    <message>
        <source>Each inquiry</source>
        <translation>Jede Frage</translation>
    </message>
    <message>
        <source>Specified location</source>
        <translation>Ange Ort</translation>
    </message>
    <message>
        <source>Select a location when saving</source>
        <translation>Beim Speichern einen Pfad festlegen</translation>
    </message>
    <message>
        <source>Update the location when saving</source>
        <translation>Beim Speichern den Pfad ändern</translation>
    </message>
</context>
<context>
    <name>Screenshot</name>
    <message>
        <source>Screen Capture will start in %1 seconds</source>
        <translation>Bildschirmaufzeichnung startet in %1 Sekunden</translation>
    </message>
</context>
<context>
    <name>ScrollShotTip</name>
    <message>
        <source>Get help.</source>
        <translation>Hilfe holen.</translation>
    </message>
    <message>
        <source>Failed to take a continuous screenshot.</source>
        <translation>Die Aufnahme eines kontinuierlichen Bildschirmfotos ist fehlgeschlagen.</translation>
    </message>
    <message>
        <source>Reached the bottom of the scroll area</source>
        <translation>Das Ende des Bildlaufbereichs erreicht</translation>
    </message>
    <message>
        <source>Reached the maximum length</source>
        <translation>Die maximale Länge wurde erreicht</translation>
    </message>
    <message>
        <source>adjust the capture area</source>
        <translation>den Aufnahmebereich anpassen</translation>
    </message>
    <message>
        <source>Scroll your mouse wheel or click to take a scrolling screenshot</source>
        <translation>Drehen Sie Ihr Mausrad oder klicken Sie, um eine rollende Bildschirmaufnahme zu machen</translation>
    </message>
    <message>
        <source>Slow down the scrolling speed</source>
        <translation>Verlangsamen Sie die Bildlaufgeschwindigkeit</translation>
    </message>
    <message>
        <source>Invalid area, click to </source>
        <translation>Ungültiger Bereich, klicken Sie</translation>
    </message>
</context>
<context>
    <name>ShapesWidget</name>
    <message>
        <source>Input text here</source>
        <translation>Hier Text eingeben</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Start/Screenshot</source>
        <translation>Start/Bildschirmaufnahme</translation>
    </message>
    <message>
        <source>Exit/Save</source>
        <translation>Beenden/Speichern</translation>
    </message>
    <message>
        <source>Size Adjustment</source>
        <translation>Größenanpassung</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>Quick start</source>
        <translation>Schnellstart</translation>
    </message>
    <message>
        <source>Window screenshot</source>
        <translation>Fensteraufnahme</translation>
    </message>
    <message>
        <source>Delay screenshot</source>
        <translation>Verzögerte Bildschirmaufnahme</translation>
    </message>
    <message>
        <source>Full screenshot</source>
        <translation>Volle Bildschirmaufnahme</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Beenden</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Speichern</translation>
    </message>
    <message>
        <source>Rectangle</source>
        <translation>Rechteck</translation>
    </message>
    <message>
        <source>Ellipse</source>
        <translation>Ellipse</translation>
    </message>
    <message>
        <source>Line</source>
        <translation>Linie</translation>
    </message>
    <message>
        <source>Pencil</source>
        <translation>Stift</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Löschen</translation>
    </message>
    <message>
        <source>Undo</source>
        <translation>Rückgängig</translation>
    </message>
    <message>
        <source>Increase height up</source>
        <translation>Höhe nach oben erweitern</translation>
    </message>
    <message>
        <source>Increase height down</source>
        <translation>Höhe nach unten erweitern</translation>
    </message>
    <message>
        <source>Increase width left</source>
        <translation>Breite nach links erweitern</translation>
    </message>
    <message>
        <source>Increase width right</source>
        <translation>Breite nach rechts erweitern</translation>
    </message>
    <message>
        <source>Decrease height up</source>
        <translation>Höhe von oben verkleinern</translation>
    </message>
    <message>
        <source>Decrease height down</source>
        <translation>Höhe von unten verkleinern</translation>
    </message>
    <message>
        <source>Decrease width left</source>
        <translation>Breite links verkleinern</translation>
    </message>
    <message>
        <source>Decrease width right</source>
        <translation>Breite rechts verkleinern</translation>
    </message>
    <message>
        <source>Help</source>
        <translation>Hilfe</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>Tastenkombinationen anzeigen</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Ton</translation>
    </message>
    <message>
        <source>Keystroke</source>
        <translation>Tastendruck</translation>
    </message>
    <message>
        <source>Webcam</source>
        <translation>Webcam</translation>
    </message>
    <message>
        <source>Start recording</source>
        <translation>Aufnahme starten</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Optionen</translation>
    </message>
    <message>
        <source>Start/Recording</source>
        <translation>Start/Aufnahme</translation>
    </message>
    <message>
        <source>Mouse</source>
        <translation>Maus</translation>
    </message>
    <message>
        <source>Tools</source>
        <translation>Werkzeuge</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>Text extrahieren</translation>
    </message>
    <message>
        <source>Scrollshot</source>
        <translation>Bildlaufaufnahme</translation>
    </message>
    <message>
        <source>Pin screenshots</source>
        <translation>Bildschirmfotos anheften</translation>
    </message>
    <message>
        <source>Start OCR</source>
        <translation>OCR starten</translation>
    </message>
    <message>
        <source>Start scrollshot</source>
        <translation>Bildlaufaufnahme starten</translation>
    </message>
    <message>
        <source>Arrow</source>
        <translation>Pfeil</translation>
    </message>
</context>
<context>
    <name>ShotStartPlugin</name>
    <message>
        <source>Screenshot</source>
        <translation>Bildschirmaufnahme</translation>
    </message>
</context>
<context>
    <name>ShotStartRecordPlugin</name>
    <message>
        <source>Record</source>
        <translation>Aufnehmen</translation>
    </message>
</context>
<context>
    <name>ShotToolWidget</name>
    <message>
        <source>Rectangle
Press and hold Shift to draw a square</source>
        <translation>Rechteck
Umschalttaste gedrückt halten, um ein Rechteck zu zeichnen</translation>
    </message>
    <message>
        <source>Ellipse
Press and hold Shift to draw a circle</source>
        <translation>Ellipse
Umschalttaste gedrückt halten, um eine Ellipse zu zeichnen</translation>
    </message>
    <message>
        <source>Brush
Press and hold Shift to draw a straight line</source>
        <translation>Pinsel
Umschalttaste gedrückt halten, um eine gerade Linie zu zeichnen</translation>
    </message>
    <message>
        <source>Adjust blur strength (Scroll to adjust it)</source>
        <translation>Verpixel-Größe einstellen (durch Scrollen)</translation>
    </message>
    <message>
        <source>Adjust brush size (Scroll to adjust it)</source>
        <translation>Pinselgröße einstellen (durch Scrollen)</translation>
    </message>
    <message>
        <source>Adjust text size (Scroll to adjust it)</source>
        <translation>Textgröße einstellen (durch Scrollen)</translation>
    </message>
</context>
<context>
    <name>SubToolWidget</name>
    <message>
        <source>Show keystroke (K)</source>
        <translation>Tastendruck anzeigen (K)</translation>
    </message>
    <message>
        <source>Hide Keystroke (K)</source>
        <translation>Tastendruck ausblenden (K)</translation>
    </message>
    <message>
        <source>Show Keystroke (K)</source>
        <translation>Tastendruck anzeigen (K)</translation>
    </message>
    <message>
        <source>Turn on camera (C)</source>
        <translation>Kamera einschalten (C)</translation>
    </message>
    <message>
        <source>Turn off camera (C)</source>
        <translation>Kamera ausschalten (C)</translation>
    </message>
    <message>
        <source>Screenshot</source>
        <translation>Bildschirmaufnahme</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Einstellungen</translation>
    </message>
    <message>
        <source>Settings (F3)</source>
        <translation>Einstellungen (F3)</translation>
    </message>
    <message>
        <source>Format:</source>
        <translation>Format:</translation>
    </message>
    <message>
        <source>GIF</source>
        <translation>GIF</translation>
    </message>
    <message>
        <source>MP4</source>
        <translation>MP4</translation>
    </message>
    <message>
        <source>MKV</source>
        <translation>MKV</translation>
    </message>
    <message>
        <source>webm</source>
        <translation>webm</translation>
    </message>
    <message>
        <source>FPS:</source>
        <translation>BpS:</translation>
    </message>
    <message>
        <source>5 fps</source>
        <translation>5 BpS</translation>
    </message>
    <message>
        <source>10 fps</source>
        <translation>10 BpS</translation>
    </message>
    <message>
        <source>20 fps</source>
        <translation>20 BpS</translation>
    </message>
    <message>
        <source>24 fps</source>
        <translation>24 BpS</translation>
    </message>
    <message>
        <source>30 fps</source>
        <translation>30 BpS</translation>
    </message>
    <message>
        <source>Sound</source>
        <translation>Ton</translation>
    </message>
    <message>
        <source>Microphone</source>
        <translation>Mikrofon</translation>
    </message>
    <message>
        <source>System audio</source>
        <translation>System-Audio</translation>
    </message>
    <message>
        <source>Options</source>
        <translation>Optionen</translation>
    </message>
    <message>
        <source>Show pointer</source>
        <translation>Zeiger anzeigen</translation>
    </message>
    <message>
        <source>Show click</source>
        <translation>Klick anzeigen</translation>
    </message>
    <message>
        <source>Save to</source>
        <translation>Speichern unter</translation>
    </message>
    <message>
        <source>Desktop</source>
        <translation>Schreibtisch</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Videos</translation>
    </message>
    <message>
        <source>Line (L)
Press and hold Shift to draw a vertical or horizontal line</source>
        <translation>Linie (L)
Umschalttaste gedrückt halten, um eine vertikale oder horizontale Linie zu zeichnen</translation>
    </message>
    <message>
        <source>Arrow (X)
Press and hold Shift to draw a vertical or horizontal arrow</source>
        <translation>Pfeil (X)
Umschalttaste gedrückt halten, um einen vertikalen oder horizontalen Pfeil zu zeichnen</translation>
    </message>
    <message>
        <source>Pencil (P)</source>
        <translation>Stift (P)</translation>
    </message>
    <message>
        <source>Blur (B)</source>
        <translation>Weichzeichnen (B)</translation>
    </message>
    <message>
        <source>Text (T)</source>
        <translation>Text (T)</translation>
    </message>
    <message>
        <source>Scrollshot (Alt+I）</source>
        <translation>Bildlaufaufnahme (Alt+I）</translation>
    </message>
    <message>
        <source>Extract text (Alt+O）</source>
        <translation>Text extrahieren (Alt+O）</translation>
    </message>
    <message>
        <source>Pin screenshots (Alt+P）</source>
        <translation>Bildschirmfotos anheften (Alt+P）</translation>
    </message>
    <message>
        <source>Undo (Ctrl+Z)</source>
        <translation>Rückgängig (Strg+Z)</translation>
    </message>
    <message>
        <source>Record</source>
        <translation>Aufnehmen</translation>
    </message>
    <message>
        <source>Change the path on save</source>
        <translation>Beim Speichern den Pfad ändern</translation>
    </message>
    <message>
        <source>Format</source>
        <translation>Format</translation>
    </message>
    <message>
        <source>PNG</source>
        <translation>PNG</translation>
    </message>
    <message>
        <source>JPG</source>
        <translation>JPG</translation>
    </message>
    <message>
        <source>BMP</source>
        <translation>BMP</translation>
    </message>
    <message>
        <source>Border Effects</source>
        <translation>Randeffekte</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Keine</translation>
    </message>
    <message>
        <source>Shadow</source>
        <translation>Schatten</translation>
    </message>
    <message>
        <source>Border</source>
        <translation>Rand</translation>
    </message>
    <message>
        <source>Device</source>
        <translation>Gerät</translation>
    </message>
    <message>
        <source>Extract Text</source>
        <translation>Text extrahieren</translation>
    </message>
    <message>
        <source>Geometric Tools (R)
Hold down Shift to draw squares or circles.</source>
        <translation>Geometrische Werkzeuge (R)
Halten Sie die Umschalttaste gedrückt, um Quadrate oder Kreise zu zeichnen.</translation>
    </message>
    <message>
        <source>Save to local</source>
        <translation>Lokal speichern</translation>
    </message>
    <message>
        <source>Save to %1</source>
        <translation>Auf %1 speichern</translation>
    </message>
    <message>
        <source>Specified Location</source>
        <translation>Ange Ort</translation>
    </message>
    <message>
        <source>Update the location when saving</source>
        <translation>Beim Speichern den Pfad ändern</translation>
    </message>
    <message>
        <source>Select a location when saving</source>
        <translation>Beim Speichern einen Pfad festlegen</translation>
    </message>
</context>
<context>
    <name>ToolBarWidget</name>
    <message>
        <source>Close (Esc)</source>
        <translation>Schließen (Esc)</translation>
    </message>
    <message>
        <source>Copy to clipboard (Enter)</source>
        <translation>In die Zwischenablage kopieren (Enter)</translation>
    </message>
    <message>
        <source>OK (Enter)</source>
        <translation>OK (Enter)</translation>
    </message>
</context>
<context>
    <name>TopTips</name>
    <message>
        <source> Adjust the recording area within %1*%2 to get better video effect</source>
        <translation>Passe den Aufnahmebereich innerhalb von %1*%2 an, um einen besseren Videoeffekt zu erhalten</translation>
    </message>
</context>
<context>
    <name>Utils</name>
    <message>
        <source>Screen recording is not supported at present</source>
        <translation>Bildschirmaufzeichnung wird derzeit nicht unterstützt</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>Beenden</translation>
    </message>
</context>
</TS>
